@@ -5,6 +5,7 @@
 use strict;
 use warnings;
 
+use Error qw(:try);
 use RT::Client::REST;
 use RT::Client::REST::Ticket;
 
@@ -18,10 +19,16 @@ my $rt = RT::Client::REST->new(
     password=> shift(@ARGV),
 );
 
-my $ticket = RT::Client::REST::Ticket->new(
-    rt  => $rt,
-    id  => shift(@ARGV),
-)->retrieve;
+my $ticket;
+try {
+    $ticket = RT::Client::REST::Ticket->new(
+        rt  => $rt,
+        id  => shift(@ARGV),
+    )->retrieve;
+} catch Exception::Class::Base with {
+    my $e = shift;
+    die ref($e), ": ", $e->message || $e->description, "\n";
+};
 
 use Data::Dumper;
 print Dumper($ticket);
